figurelib package
=================

Submodules
----------

figurelib.building module
-------------------------

.. automodule:: figurelib.building
   :members:
   :undoc-members:
   :show-inheritance:

figurelib.figure module
-----------------------

.. automodule:: figurelib.figure
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: figurelib
   :members:
   :undoc-members:
   :show-inheritance:
